@@ -61,7 +61,6 @@ void CreateDialogTest::testBasicWidgets_data()
     QTest::newRow("tarZ") << QStringLiteral("application/x-tarz");
     QTest::newRow("tarxz") << QStringLiteral("application/x-xz-compressed-tar");
     QTest::newRow("tarlzma") << QStringLiteral("application/x-lzma-compressed-tar");
-    QTest::newRow("tarlzop") << QStringLiteral("application/x-tzo");
     QTest::newRow("tarlzip") << QStringLiteral("application/x-lzip-compressed-tar");
 
     const auto writeMimeTypes = m_pluginManager.supportedWriteMimeTypes();
@@ -89,11 +88,17 @@ void CreateDialogTest::testBasicWidgets_data()
     } else {
         qDebug() << "tar.lrzip format not available in CreateDialog, skipping test.";
     }
+
+    if (writeMimeTypes.contains(QStringLiteral("application/x-tzo"))) {
+        QTest::newRow("tarlzop") << QStringLiteral("application/x-tzo");
+    } else {
+        qDebug() << "tar.lzo format not available in CreateDialog, skipping test.";
+    }
 }
 
 void CreateDialogTest::testBasicWidgets()
 {
-    CreateDialog *dialog = new CreateDialog(Q_NULLPTR, QString(), QUrl());
+    CreateDialog *dialog = new CreateDialog(nullptr, QString(), QUrl());
 
     auto fileNameLineEdit = dialog->findChild<QLineEdit*>(QStringLiteral("filenameLineEdit"));
     auto archiveTypeComboBox = dialog->findChild<QComboBox*>(QStringLiteral("mimeComboBox"));
@@ -142,7 +147,7 @@ void CreateDialogTest::testEncryption_data()
 
 void CreateDialogTest::testEncryption()
 {
-    CreateDialog *dialog = new CreateDialog(Q_NULLPTR, QString(), QUrl());
+    CreateDialog *dialog = new CreateDialog(nullptr, QString(), QUrl());
 
     QFETCH(QString, filter);
     QFETCH(bool, isEncryptionAvailable);
@@ -193,7 +198,7 @@ void CreateDialogTest::testHeaderEncryptionTooltip()
         QSKIP("zip format not available in CreateDialog, skipping test.", SkipSingle);
     }
 
-    CreateDialog *dialog = new CreateDialog(Q_NULLPTR, QString(), QUrl());
+    CreateDialog *dialog = new CreateDialog(nullptr, QString(), QUrl());
 
     auto collapsibleEncryption = dialog->findChild<KCollapsibleGroupBox*>(QStringLiteral("collapsibleEncryption"));
     auto encryptHeaderCheckBox = dialog->findChild<QCheckBox*>(QStringLiteral("encryptHeaderCheckBox"));
