@@ -23,8 +23,7 @@
 
 #include "cliplugin.h"
 #include "ark_debug.h"
-#include "kerfuffle/cliinterface.h"
-#include "kerfuffle/kerfuffle_export.h"
+#include "cliinterface.h"
 
 #include <QDateTime>
 #include <QDir>
@@ -266,7 +265,7 @@ bool CliPlugin::readListLine(const QString& line)
             else {
                 delete m_currentArchiveEntry;
             }
-            m_currentArchiveEntry = Q_NULLPTR;
+            m_currentArchiveEntry = nullptr;
         }
     }
 
@@ -275,10 +274,28 @@ bool CliPlugin::readListLine(const QString& line)
 
 bool CliPlugin::readExtractLine(const QString &line)
 {
-    QRegularExpression rx(QStringLiteral("ERROR: E_FAIL"));
+    const QRegularExpression rxUnknownError(QStringLiteral("ERROR: E_FAIL"));
+    const QRegularExpression rxBadCRC(QStringLiteral("ERROR: CRC Failed"));
+
+    if (rxUnknownError.match(line).hasMatch()) {
+        emit error(i18n("Extraction failed due to an unknown error."));
+        return false;
+    }
+
+    if (rxBadCRC.match(line).hasMatch()) {
+        emit error(i18n("Extraction failed due to one or more corrupt files. Any extracted files may be damaged."));
+        return false;
+    }
+
+    return true;
+}
+
+bool CliPlugin::readDeleteLine(const QString &line)
+{
+    QRegularExpression rx(QStringLiteral("Error: .+ is not supported archive"));
 
     if (rx.match(line).hasMatch()) {
-        emit error(i18n("Extraction failed."));
+        emit error(i18n("Delete operation failed. Try upgrading p7zip or disabling the p7zip plugin in the configuration dialog."));
         return false;
     }
 
